@@ -69,6 +69,11 @@ def integration_test():
 
     return decorating_function
 
+def _safe_get_item(key):
+    try:
+        return NodeMappingType[f'Input{str(key)}']
+    except ValueError:
+        raise Exception(f'Tensorleap currently supports models with no more then 10 inputs')
 
 def tensorleap_load_model(prediction_types: Optional[List[PredictionTypeHandler]] = None):
     for i, prediction_type in enumerate(prediction_types):
@@ -92,6 +97,20 @@ def tensorleap_load_model(prediction_types: Optional[List[PredictionTypeHandler]
                 def _convert_onnx_inputs_to_correct_type(
                         self, float_arrays_inputs: Dict[str, np.ndarray]
                 ) -> Dict[str, np.ndarray]:
+                    ONNX_TYPE_TO_NP = {
+                        "tensor(float)": np.float32,
+                        "tensor(double)": np.float64,
+                        "tensor(int64)": np.int64,
+                        "tensor(int32)": np.int32,
+                        "tensor(int16)": np.int16,
+                        "tensor(int8)": np.int8,
+                        "tensor(uint64)": np.uint64,
+                        "tensor(uint32)": np.uint32,
+                        "tensor(uint16)": np.uint16,
+                        "tensor(uint8)": np.uint8,
+                        "tensor(bool)": np.bool_,
+                    }
+
                     """
                     Cast user-provided NumPy inputs to match the dtypes/shapes
                     expected by an ONNX Runtime InferenceSession.
@@ -106,7 +125,11 @@ def tensorleap_load_model(prediction_types: Optional[List[PredictionTypeHandler]
                             continue
 
                         info = meta[name]
-                        want_dtype = np.dtype(info.type)  # ONNX Runtime gives NumPy dtype string
+                        onnx_type = info.type
+                        want_dtype = ONNX_TYPE_TO_NP.get(onnx_type)
+
+                        if want_dtype is None:
+                            raise TypeError(f"Unsupported ONNX input type: {onnx_type}")
 
                         # Cast dtype if needed
                         if arr.dtype != want_dtype:
@@ -141,15 +164,20 @@ def tensorleap_load_model(prediction_types: Optional[List[PredictionTypeHandler]
                         f'Expected key to be an int, got {type(key)} instead.'
 
                     ret = TempMapping()
-                    ret.node_mapping = NodeMapping('', NodeMappingType(f'Prediction{str(key)}'))
+                    try:
+                        ret.node_mapping = NodeMapping('', NodeMappingType(f'Prediction{str(key)}'))
+                    except ValueError as e:
+                        raise Exception(f'Tensorleap currently supports models with no more then 10 active predictions,'
+                                        f' {key} not supported.')
                     return ret
 
             class ModelPlaceholder:
+
                 # keras interface
                 def __call__(self, arg):
                     if isinstance(arg, list):
                         for i, elem in enumerate(arg):
-                            elem.node_mapping.type = NodeMappingType[f'Input{str(i)}']
+                            elem.node_mapping.type = _safe_get_item(i)
                     else:
                         arg.node_mapping.type = NodeMappingType.Input0
 
@@ -164,14 +192,14 @@ def tensorleap_load_model(prediction_types: Optional[List[PredictionTypeHandler]
                         if isinstance(input_key, NodeMappingType):
                             elem.node_mapping.type = input_key
                         else:
-                            elem.node_mapping.type = NodeMappingType[f'Input{str(i)}']
+                            elem.node_mapping.type = _safe_get_item(i)
 
                     return ModelOutputPlaceholder()
 
                 def get_inputs(self):
                     class FollowIndex:
                         def __init__(self, index):
-                            self.name =  NodeMappingType[f'Input{str(i)}']
+                            self.name =  _safe_get_item(index)
 
                     class FollowInputIndex:
                         def __init__(self):
@@ -846,6 +874,7 @@ def tensorleap_input_encoder(name: str, channel_dim=-1, model_input_index=None):
             ret = TempMapping()
             ret.node_mapping = mapping_inner.node_mapping
 
+            leap_binder.mapping_connections.append(NodeConnection(mapping_inner.node_mapping, None))
             return ret
 
         mapping_inner.node_mapping = NodeMapping(name, node_mapping_type)
